"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.flacWriter = exports.FlacWriter = void 0;
const metadata_writer_1 = require("../metadata-writer");
const flac_tagger_1 = require("flac-tagger");
const getVorbisComments = (metadata) => {
    const tagMap = {
        artist: metadata.artists,
        title: metadata.title,
        album: metadata.album,
        albumSort: metadata.albumOrder,
        trackNumber: metadata.trackNumber,
        discNumber: metadata.discNumber,
    };
    if (metadata.composers) {
        tagMap.composer = metadata.composers;
    }
    if (metadata.comments) {
        tagMap.comment = metadata.comments;
    }
    if (metadata.lyric) {
        tagMap.lyric = metadata.lyric;
    }
    if (metadata.lyricists) {
        tagMap.lyricist = metadata.lyricists;
    }
    if (metadata.albumArtists) {
        tagMap.albumArtist = metadata.albumArtists;
    }
    if (metadata.genres) {
        tagMap.genre = metadata.genres;
    }
    if (metadata.year) {
        tagMap.date = metadata.year;
    }
    return tagMap;
};
class FlacWriter extends metadata_writer_1.MetadataWriter {
    async write(metadata, filePath) {
        await (0, flac_tagger_1.writeFlacTags)({
            tagMap: getVorbisComments(metadata),
            picture: metadata.coverImage
                ? {
                    description: metadata.album,
                    buffer: metadata.coverImage,
                }
                : undefined,
        }, filePath);
    }
}
exports.FlacWriter = FlacWriter;
exports.flacWriter = new FlacWriter();
